package Bundle::COG;

$VERSION = '0.05';

=head1 NAME

Bundle::COG - Install all modules by COG

=head1 SYNOPSIS

cpan Bundle::COG

=head1 CONTENTS

Acme::AsciiArt2HtmlTable

Business::PT::BI

Business::PT::NIF

Date::Holidays::PT

File::Munger

Filesys::DiskUsage

Filesys::Tree

Games::PetalsAroundTheRose

Games::Messages

Games::Score

Lingua::Identify

Lingua::PT::Hyphenate

Lingua::PT::Inflect

Lingua::PT::Nums2Ords

Lingua::PT::Nums2Words

Lingua::PT::Ords2Nums

Lingua::PT::Words2Nums

Mail::LocalDelivery

Number::Phone::PT

PT::PostalCode

Test::RandomResults

Text::Affixes

Text::Beautify

Text::Ngram

WWW::Dictionary

=head1 AUTHOR

Jose Castro, C<< <cog@cpan.org> >>

=head1 COPYRIGHT & LICENSE

Copyright 2004 Jose Castro, All Rights Reserved.

This program is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1; # End of Bundle::COG
